@@ -14,15 +14,16 @@
 #include "base/Log.h"
 #include "client/Client.h"
 #include "common/Constants.h"
+#include "common/ExitCodes.h"
 #include "deskflow/ArgParser.h"
 #include "deskflow/ClientArgs.h"
 #include "deskflow/ProtocolTypes.h"
 #include "deskflow/Screen.h"
-#include "deskflow/XScreen.h"
+#include "deskflow/ScreenException.h"
 #include "net/NetworkAddress.h"
+#include "net/SocketException.h"
 #include "net/SocketMultiplexer.h"
 #include "net/TCPSocketFactory.h"
-#include "net/XSocket.h"
 #include "platform/Wayland.h"
 
 #if SYSAPI_WIN32
@@ -72,9 +73,9 @@ void ClientApp::parseArgs(int argc, const char *const *argv)
 
   if (!result || args().m_shouldExitOk || args().m_shouldExitFail) {
     if (args().m_shouldExitOk) {
-      m_bye(s_exitSuccess);
+      bye(s_exitSuccess);
     } else {
-      m_bye(s_exitArgs);
+      bye(s_exitArgs);
     }
   } else {
     // save server address
@@ -82,14 +83,14 @@ void ClientApp::parseArgs(int argc, const char *const *argv)
       try {
         *m_serverAddress = NetworkAddress(args().m_serverAddress, kDefaultPort);
         m_serverAddress->resolve();
-      } catch (XSocketAddress &e) {
+      } catch (SocketAddressException &e) {
         // allow an address that we can't look up if we're restartable.
         // we'll try to resolve the address each time we connect to the
         // server.  a bad port will never get better.  patch by Brent
         // Priddy.
-        if (!args().m_restartable || e.getError() == XSocketAddress::SocketError::BadPort) {
-          LOG((CLOG_CRIT "%s: %s" BYE, args().m_pname, e.what(), args().m_pname));
-          m_bye(s_exitFailed);
+        if (!args().m_restartable || e.getError() == SocketAddressException::SocketError::BadPort) {
+          LOG_CRIT("%s: %s" BYE, args().m_pname, e.what(), args().m_pname);
+          bye(s_exitFailed);
         }
       }
     }
@@ -99,7 +100,9 @@ void ClientApp::parseArgs(int argc, const char *const *argv)
 void ClientApp::help()
 {
   std::stringstream help;
-  help << "Usage: " << args().m_pname << " [--address <address>]"
+  help << "\n\nClient Mode:\n\n"
+       << "Usage: " << kAppId << "-core client"
+       << " [--address <address>]"
        << " [--yscroll <delta>]"
        << " [--sync-language]"
        << " [--invert-scroll]"
@@ -130,7 +133,7 @@ void ClientApp::help()
        << "The hostname must be the address or hostname of the server.\n"
        << "The port overrides the default port, " << kDefaultPort << ".\n";
 
-  LOG((CLOG_PRINT "%s", help.str().c_str()));
+  LOG_PRINT("%s", help.str().c_str());
 }
 
 const char *ClientApp::daemonName() const
@@ -156,16 +159,20 @@ deskflow::Screen *ClientApp::createScreen()
 {
 #if WINAPI_MSWINDOWS
   return new deskflow::Screen(
-      new MSWindowsScreen(false, args().m_noHooks, m_events, args().m_enableLangSync, args().m_clientScrollDirection),
-      m_events
+      new MSWindowsScreen(
+          false, args().m_noHooks, getEvents(), args().m_enableLangSync, args().m_clientScrollDirection
+      ),
+      getEvents()
   );
 #endif
 
 #if defined(WINAPI_XWINDOWS) or defined(WINAPI_LIBEI)
   if (deskflow::platform::isWayland()) {
 #if WINAPI_LIBEI
-    LOG((CLOG_INFO "using ei screen for wayland"));
-    return new deskflow::Screen(new deskflow::EiScreen(false, m_events, true), m_events);
+    LOG_INFO("using ei screen for wayland");
+    return new deskflow::Screen(
+        new deskflow::EiScreen(false, getEvents(), true, args().m_clientScrollDirection), getEvents()
+    );
 #else
     throw XNoEiSupport();
 #endif
@@ -173,40 +180,25 @@ deskflow::Screen *ClientApp::createScreen()
 #endif
 
 #if WINAPI_XWINDOWS
-  LOG((CLOG_INFO "using legacy x windows screen"));
+  LOG_INFO("using legacy x windows screen");
   return new deskflow::Screen(
-      new XWindowsScreen(args().m_display, false, args().m_yscroll, m_events, args().m_clientScrollDirection), m_events
+      new XWindowsScreen(args().m_display, false, args().m_yscroll, getEvents(), args().m_clientScrollDirection),
+      getEvents()
   );
 
 #endif
 
 #if WINAPI_CARBON
   return new deskflow::Screen(
-      new OSXScreen(m_events, false, args().m_enableLangSync, args().m_clientScrollDirection), m_events
+      new OSXScreen(getEvents(), false, args().m_enableLangSync, args().m_clientScrollDirection), getEvents()
   );
 #endif
 }
 
-void ClientApp::updateStatus() const
-{
-  updateStatus("");
-}
-
-void ClientApp::updateStatus(const std::string_view &) const
-{
-  // do nothing
-}
-
-void ClientApp::handleScreenError()
-{
-  LOG((CLOG_CRIT "error on screen"));
-  m_events->addEvent(Event(EventTypes::Quit));
-}
-
 deskflow::Screen *ClientApp::openClientScreen()
 {
   deskflow::Screen *screen = createScreen();
-  m_events->addHandler(EventTypes::ScreenError, screen->getEventTarget(), [this](const auto &) {
+  getEvents()->addHandler(EventTypes::ScreenError, screen->getEventTarget(), [this](const auto &) {
     handleScreenError();
   });
   return screen;
@@ -215,7 +207,7 @@ deskflow::Screen *ClientApp::openClientScreen()
 void ClientApp::closeClientScreen(deskflow::Screen *screen)
 {
   if (screen != nullptr) {
-    m_events->removeHandler(EventTypes::ScreenError, screen->getEventTarget());
+    getEvents()->removeHandler(EventTypes::ScreenError, screen->getEventTarget());
     delete screen;
   }
 }
@@ -223,8 +215,8 @@ void ClientApp::closeClientScreen(deskflow::Screen *screen)
 void ClientApp::handleClientRestart(const Event &, EventQueueTimer *timer)
 {
   // discard old timer
-  m_events->deleteTimer(timer);
-  m_events->removeHandler(EventTypes::Timer, timer);
+  getEvents()->deleteTimer(timer);
+  getEvents()->removeHandler(EventTypes::Timer, timer);
 
   // reconnect
   startClient();
@@ -233,15 +225,14 @@ void ClientApp::handleClientRestart(const Event &, EventQueueTimer *timer)
 void ClientApp::scheduleClientRestart(double retryTime)
 {
   // install a timer and handler to retry later
-  LOG((CLOG_DEBUG "retry in %.0f seconds", retryTime));
-  EventQueueTimer *timer = m_events->newOneShotTimer(retryTime, nullptr);
-  m_events->addHandler(EventTypes::Timer, timer, [this, timer](const auto &e) { handleClientRestart(e, timer); });
+  LOG_DEBUG("retry in %.0f seconds", retryTime);
+  EventQueueTimer *timer = getEvents()->newOneShotTimer(retryTime, nullptr);
+  getEvents()->addHandler(EventTypes::Timer, timer, [this, timer](const auto &e) { handleClientRestart(e, timer); });
 }
 
 void ClientApp::handleClientConnected() const
 {
-  LOG((CLOG_NOTE "connected to server"));
-  updateStatus();
+  LOG_IPC("connected to server");
 }
 
 void ClientApp::handleClientFailed(const Event &e)
@@ -249,8 +240,7 @@ void ClientApp::handleClientFailed(const Event &e)
   if ((++m_lastServerAddressIndex) < m_client->getLastResolvedAddressesCount()) {
     std::unique_ptr<Client::FailInfo> info(static_cast<Client::FailInfo *>(e.getData()));
 
-    updateStatus(std::string("Failed to connect to server: ") + info->m_what + " Trying next address...");
-    LOG((CLOG_WARN "failed to connect to server=%s, trying next address", info->m_what.c_str()));
+    LOG_WARN("failed to connect to server=%s, trying next address", info->m_what.c_str());
     if (!m_suspended) {
       scheduleClientRestart(s_retryTime);
     }
@@ -264,12 +254,11 @@ void ClientApp::handleClientRefused(const Event &e)
 {
   std::unique_ptr<Client::FailInfo> info(static_cast<Client::FailInfo *>(e.getData()));
 
-  updateStatus(std::string("Failed to connect to server: ") + info->m_what);
   if (!args().m_restartable || !info->m_retry) {
-    LOG((CLOG_ERR "failed to connect to server: %s", info->m_what.c_str()));
-    m_events->addEvent(Event(EventTypes::Quit));
+    LOG_ERR("failed to connect to server: %s", info->m_what.c_str());
+    getEvents()->addEvent(Event(EventTypes::Quit));
   } else {
-    LOG((CLOG_WARN "failed to connect to server: %s", info->m_what.c_str()));
+    LOG_WARN("failed to connect to server: %s", info->m_what.c_str());
     if (!m_suspended) {
       scheduleClientRestart(s_retryTime);
     }
@@ -278,30 +267,29 @@ void ClientApp::handleClientRefused(const Event &e)
 
 void ClientApp::handleClientDisconnected()
 {
-  LOG((CLOG_NOTE "disconnected from server"));
+  LOG_IPC("disconnected from server");
   if (!args().m_restartable) {
-    m_events->addEvent(Event(EventTypes::Quit));
+    getEvents()->addEvent(Event(EventTypes::Quit));
   } else if (!m_suspended) {
     scheduleClientRestart(s_retryTime);
   }
-  updateStatus();
 }
 
 Client *ClientApp::openClient(const std::string &name, const NetworkAddress &address, deskflow::Screen *screen)
 {
-  auto *client = new Client(m_events, name, address, getSocketFactory(), screen, args());
+  auto *client = new Client(getEvents(), name, address, getSocketFactory(), screen, args());
 
   try {
-    m_events->addHandler(EventTypes::ClientConnected, client->getEventTarget(), [this](const auto &) {
+    getEvents()->addHandler(EventTypes::ClientConnected, client->getEventTarget(), [this](const auto &) {
       handleClientConnected();
     });
-    m_events->addHandler(EventTypes::ClientConnectionFailed, client->getEventTarget(), [this](const auto &e) {
+    getEvents()->addHandler(EventTypes::ClientConnectionFailed, client->getEventTarget(), [this](const auto &e) {
       handleClientFailed(e);
     });
-    m_events->addHandler(EventTypes::ClientConnectionRefused, client->getEventTarget(), [this](const auto &e) {
+    getEvents()->addHandler(EventTypes::ClientConnectionRefused, client->getEventTarget(), [this](const auto &e) {
       handleClientRefused(e);
     });
-    m_events->addHandler(EventTypes::ClientDisconnected, client->getEventTarget(), [this](const auto &) {
+    getEvents()->addHandler(EventTypes::ClientDisconnected, client->getEventTarget(), [this](const auto &) {
       handleClientDisconnected();
     });
 
@@ -319,10 +307,10 @@ void ClientApp::closeClient(Client *client)
     return;
   }
   using enum EventTypes;
-  m_events->removeHandler(ClientConnected, client);
-  m_events->removeHandler(ClientConnectionFailed, client);
-  m_events->removeHandler(ClientConnectionRefused, client);
-  m_events->removeHandler(ClientDisconnected, client);
+  getEvents()->removeHandler(ClientConnected, client);
+  getEvents()->removeHandler(ClientConnectionFailed, client);
+  getEvents()->removeHandler(ClientConnectionRefused, client);
+  getEvents()->removeHandler(ClientDisconnected, client);
   delete client;
 }
 
@@ -343,24 +331,22 @@ bool ClientApp::startClient()
       clientScreen = openClientScreen();
       m_client = openClient(args().m_name, *m_serverAddress, clientScreen);
       m_clientScreen = clientScreen;
-      LOG((CLOG_NOTE "started client"));
+      LOG_NOTE("started client");
     }
 
     m_client->connect(m_lastServerAddressIndex);
 
-    updateStatus();
     return true;
-  } catch (XScreenUnavailable &e) {
-    LOG((CLOG_WARN "secondary screen unavailable: %s", e.what()));
+  } catch (ScreenUnavailableException &e) {
+    LOG_WARN("secondary screen unavailable: %s", e.what());
     closeClientScreen(clientScreen);
-    updateStatus(std::string("secondary screen unavailable: ") + e.what());
     retryTime = e.getRetryTime();
-  } catch (XScreenOpenFailure &e) {
-    LOG((CLOG_CRIT "failed to start client: %s", e.what()));
+  } catch (ScreenOpenFailureException &e) {
+    LOG_CRIT("failed to start client: %s", e.what());
     closeClientScreen(clientScreen);
     return false;
-  } catch (XBase &e) {
-    LOG((CLOG_CRIT "failed to start client: %s", e.what()));
+  } catch (BaseException &e) {
+    LOG_CRIT("failed to start client: %s", e.what());
     closeClientScreen(clientScreen);
     return false;
   }
@@ -406,16 +392,15 @@ int ClientApp::mainLoop()
 
   runCocoaApp();
 #else
-  m_events->loop();
+  getEvents()->loop();
 #endif
 
   DAEMON_RUNNING(false);
 
   // close down
-  LOG((CLOG_DEBUG1 "stopping client"));
+  LOG_DEBUG1("stopping client");
   stopClient();
-  updateStatus();
-  LOG((CLOG_NOTE "stopped client"));
+  LOG_NOTE("stopped client");
 
   return s_exitSuccess;
 }
@@ -460,13 +445,13 @@ void ClientApp::startNode()
 {
   // start the client.  if this return false then we've failed and
   // we shouldn't retry.
-  LOG((CLOG_DEBUG1 "starting client"));
+  LOG_DEBUG1("starting client");
   if (!startClient()) {
-    m_bye(s_exitFailed);
+    bye(s_exitFailed);
   }
 }
 
 ISocketFactory *ClientApp::getSocketFactory() const
 {
-  return new TCPSocketFactory(m_events, getSocketMultiplexer());
+  return new TCPSocketFactory(getEvents(), getSocketMultiplexer());
 }
