@@ -16,8 +16,8 @@ class IEventQueue;
 class AppUtilUnix : public AppUtil
 {
 public:
-  AppUtilUnix(IEventQueue *events);
-  virtual ~AppUtilUnix();
+  explicit AppUtilUnix(const IEventQueue *);
+  ~AppUtilUnix() override = default;
 
   int run(int argc, char **argv) override;
   void startNode() override;
