@@ -10,7 +10,7 @@
 class OSXClipboardTests : public QObject
 {
   Q_OBJECT
-private slots:
+private Q_SLOTS:
   // Test are run in order top to bottom
   void open();
   void singleFormat();
